@@ -5,15 +5,17 @@
 
 import warnings
 from pathlib import Path
-from typing import Any, Dict, Optional, Union
+from typing import Any, Optional, Union
 
+from ._version import __version__
 from .chart import ChartService
 from .client import Lims2Client
 from .exceptions import APIError, AuthError, ConfigError, Lims2Error, UploadError
 from .storage import StorageService
 
-__version__ = "0.4.2"
 __all__ = [
+    # 版本信息
+    "__version__",
     # 主要接口
     "Lims2Client",
     "ChartService",
@@ -35,14 +37,14 @@ __all__ = [
 def upload_chart_from_data(
     chart_name: str,
     project_id: str,
-    chart_data: Dict[str, Any],
+    chart_data: dict[str, Any],
     sample_id: Optional[str] = None,
     chart_type: Optional[str] = None,
     description: Optional[str] = None,
     contrast: Optional[str] = None,
     analysis_node: Optional[str] = None,
     precision: Optional[int] = 3,
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     """上传图表数据（向后兼容函数）
 
     .. deprecated:: 0.4.1
@@ -66,7 +68,7 @@ def upload_chart_from_data(
     """
     warnings.warn(
         "upload_chart_from_data() 已弃用，建议使用 Lims2Client 实例方法复用连接池，"
-        "避免批量上传时的连接问题。将在 v0.5.0 中移除。",
+        "避免批量上传时的连接问题。",
         DeprecationWarning,
         stacklevel=2,
     )
@@ -94,7 +96,7 @@ def upload_chart_from_file(
     contrast: Optional[str] = None,
     analysis_node: Optional[str] = None,
     precision: Optional[int] = 3,
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     """上传图表文件（向后兼容函数）
 
     .. deprecated:: 0.4.1
@@ -118,7 +120,7 @@ def upload_chart_from_file(
     """
     warnings.warn(
         "upload_chart_from_file() 已弃用，建议使用 Lims2Client 实例方法复用连接池，"
-        "避免批量上传时的连接问题。将在 v0.5.0 中移除。",
+        "避免批量上传时的连接问题。",
         DeprecationWarning,
         stacklevel=2,
     )
@@ -142,7 +144,7 @@ def upload_result_file(
     analysis_node: str,
     sample_id: Optional[str] = None,
     description: Optional[str] = None,
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     """上传结果文件（便捷函数）
 
     .. deprecated:: 0.4.1
@@ -162,7 +164,7 @@ def upload_result_file(
     """
     warnings.warn(
         "upload_result_file() 已弃用，建议使用 Lims2Client 实例方法复用连接池，"
-        "避免批量上传时的连接问题。将在 v0.5.0 中移除。",
+        "避免批量上传时的连接问题。",
         DeprecationWarning,
         stacklevel=2,
     )
@@ -203,7 +205,7 @@ def upload_result_dir(
     """
     warnings.warn(
         "upload_result_dir() 已弃用，建议使用 Lims2Client 实例方法复用连接池，"
-        "避免批量上传时的连接问题。将在 v0.5.0 中移除。",
+        "避免批量上传时的连接问题。",
         DeprecationWarning,
         stacklevel=2,
     )
