@@ -5,12 +5,12 @@
 
 import gzip
 from pathlib import Path
-from typing import Any, Dict, Optional, Union
+from typing import Any, Optional, Union
 
 import orjson
-import requests
 
-from .exceptions import UploadError
+from .network import network_retry
+from .oss_base import OSSMixin
 from .utils import (
     format_file_size,
     generate_unique_filename,
@@ -21,11 +21,11 @@ from .utils import (
     round_floats,
 )
 
-# 内联存储阈值 200KB
-INLINE_STORAGE_THRESHOLD = 200 * 1024
+# 内联存储阈值 1Byte , 都存到OSS
+INLINE_STORAGE_THRESHOLD = 1
 
 
-class ChartService:
+class ChartService(OSSMixin):
     """图表服务"""
 
     def __init__(self, client):
@@ -38,9 +38,12 @@ class ChartService:
         self.config = client.config
         self.session = client.session
 
+        # 初始化OSS混入功能
+        self.__init_oss__()
+
     def upload(
         self,
-        data_source: Union[Dict[str, Any], str, Path],
+        data_source: Union[dict[str, Any], str, Path],
         project_id: str,
         chart_name: str,
         sample_id: Optional[str] = None,
@@ -49,7 +52,7 @@ class ChartService:
         contrast: Optional[str] = None,
         analysis_node: Optional[str] = None,
         precision: Optional[int] = None,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """上传图表
 
         Args:
@@ -102,10 +105,10 @@ class ChartService:
 
     def _upload_from_dict(
         self,
-        request_data: Dict[str, Any],
-        chart_data: Dict[str, Any],
+        request_data: dict[str, Any],
+        chart_data: dict[str, Any],
         precision: Optional[int] = None,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """从字典数据上传图表"""
         # 检测渲染器类型
         if "data" in chart_data and "layout" in chart_data:
@@ -149,19 +152,24 @@ class ChartService:
             # 大数据压缩后上传到 OSS
             compressed_data = gzip.compress(json_str.encode("utf-8"))
 
-            # 生成文件名
-            filename = generate_unique_filename(request_data["chart_name"], "json.gz")
+            # 生成文件名（使用.json后缀，虽然内容是gzip压缩的）
+            filename = generate_unique_filename(request_data["chart_name"], "json")
 
-            # 获取签名 URL
-            signed_url, oss_key = self._get_oss_signed_url(
+            # 构建OSS键名并上传到OSS
+            oss_key = self._build_chart_oss_key(
                 request_data["project_id"], request_data.get("sample_id"), filename
             )
+            bucket = self._get_oss_bucket(request_data["project_id"])
+            bucket.put_object(
+                oss_key,
+                compressed_data,
+                headers={
+                    "Content-Type": "application/json",
+                    "Content-Encoding": "gzip",
+                },
+            )
 
-            # 上传到 OSS
-            if not self._upload_to_oss(signed_url, compressed_data, "application/gzip"):
-                raise UploadError("上传到 OSS 失败")
-
-            request_data["file_format"] = "json.gz"
+            request_data["file_format"] = "json"  # 记录格式为json，实际内容是gzip压缩的
             request_data["file_name"] = filename
             request_data["oss_key"] = oss_key
         else:
@@ -175,12 +183,12 @@ class ChartService:
         # 创建图表记录
         return self._create_chart_record(request_data)
 
-    def _upload_from_file(
+    def _upload_from_file(  # noqa: C901
         self,
-        request_data: Dict[str, Any],
+        request_data: dict[str, Any],
         file_path: Union[str, Path],
         precision: Optional[int] = None,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """从文件上传图表"""
         file_path = Path(file_path)
 
@@ -216,8 +224,8 @@ class ChartService:
         filename = generate_unique_filename(request_data["chart_name"], file_format)
         request_data["file_name"] = filename
 
-        # 获取签名 URL
-        signed_url, oss_key = self._get_oss_signed_url(
+        # 构建OSS键名
+        oss_key = self._build_chart_oss_key(
             request_data["project_id"], request_data.get("sample_id"), filename
         )
 
@@ -228,86 +236,57 @@ class ChartService:
 
         # 上传到 OSS
         content_type = self._get_content_type(file_format)
-        if not self._upload_to_oss(signed_url, file_content, content_type):
-            raise UploadError("上传到 OSS 失败")
+        bucket = self._get_oss_bucket(request_data["project_id"])
+        bucket.put_object(oss_key, file_content, headers={"Content-Type": content_type})
 
         request_data["oss_key"] = oss_key
 
         # 创建图表记录
         return self._create_chart_record(request_data)
 
-    def _get_oss_signed_url(
-        self, project_id: str, sample_id: Optional[str], file_name: str
-    ) -> tuple:
-        """获取 OSS 签名 URL"""
-        request_data = {"project_id": project_id, "file_name": file_name}
+    def _build_chart_oss_key(
+        self, project_id: str, sample_id: Optional[str], filename: str
+    ) -> str:
+        """构建图表的OSS键名
 
+        Args:
+            project_id: 项目ID
+            sample_id: 样本ID（可选）
+            filename: 文件名
+
+        Returns:
+            str: OSS键名，格式为biochart/{env}/project_id/[sample_id/]filename
+            - 环境前缀：生产环境使用media，测试环境使用test
+        """
+        # 使用环境相关的路径前缀
+        env_prefix = self._get_oss_path_prefix()
+        parts = ["biochart", env_prefix, project_id]
         if sample_id:
-            request_data["sample_id"] = sample_id
+            parts.append(sample_id)
+        parts.append(filename)
+        return "/".join(parts)
 
-        request_data["token"] = self.config.token
-        request_data["team_id"] = self.config.team_id
-
-        try:
-            response = self.session.post(
-                f"{self.config.api_url}/get_data/biochart/get_upload_url/",
-                json=request_data,
-                timeout=self.config.timeout,
-            )
-            result = handle_api_response(response, "获取上传签名 URL")
-            return result["record"]["signed_url"], result["record"]["oss_key"]
-        except Exception as e:
-            # 对于批量上传时的连接错误，提供更详细的错误信息
-            if "Name or service not known" in str(e):
-                raise UploadError(
-                    f"DNS 解析失败（批量上传时偶发）: {str(e)}\n"
-                    f"建议：1) 使用客户端方法Lims2Client，复用链接池，不要使用便捷函数 2) 增加重试间隔 3) 检查本地DNS配置"
-                )
-            raise
-
-    def _upload_to_oss(
-        self,
-        signed_url: str,
-        data: bytes,
-        content_type: str = "application/octet-stream",
-    ) -> bool:
-        """上传数据到 OSS"""
-        headers = {"Content-Type": content_type}
-        # 使用独立会话，避免泄露认证信息
-        with requests.Session() as session:
-            response = session.put(
-                signed_url, data=data, headers=headers, timeout=self.config.timeout
-            )
-            return response.status_code == 200
-
-    def _create_chart_record(self, request_data: Dict[str, Any]) -> Dict[str, Any]:
+    @network_retry(max_retries=3, base_delay=1.0, max_delay=15.0)
+    def _create_chart_record(self, request_data: dict[str, Any]) -> dict[str, Any]:
         """创建图表记录"""
 
         request_data["token"] = self.config.token
         request_data["team_id"] = self.config.team_id
 
-        try:
-            response = self.session.post(
-                f"{self.config.api_url}/get_data/biochart/create_chart/",
-                json=request_data,
-                timeout=self.config.timeout,
-            )
-            return handle_api_response(response, "创建图表记录")
-        except Exception as e:
-            # 对于批量上传时的连接错误，提供更详细的错误信息
-            if "Name or service not known" in str(e):
-                raise UploadError(
-                    f"DNS 解析失败（批量上传时偶发）: {str(e)}\n"
-                    f"当前图表: {request_data.get('chart_name', '未知')}\n"
-                    f"建议：1) 使用客户端方法Lims2Client，复用链接池，不要使用便捷函数 2) 增加重试间隔 3) 检查本地DNS配置"
-                )
-            raise
+        # 使用配置的超时时间和分离的连接/读取超时
+        timeout = (self.config.connection_timeout, self.config.read_timeout)
+
+        response = self.session.post(
+            f"{self.config.api_url}/get_data/biochart/create_chart/",
+            json=request_data,
+            timeout=timeout,
+        )
+        return handle_api_response(response, "创建图表记录")
 
     def _get_content_type(self, file_format: str) -> str:
         """获取文件内容类型"""
         content_types = {
             "json": "application/json",
-            "json.gz": "application/gzip",
             "png": "image/png",
             "jpg": "image/jpeg",
             "jpeg": "image/jpeg",
