@@ -1,10 +1,16 @@
 """异常定义"""
 
+from ._version import __version__
+
 
 class Lims2Error(Exception):
     """Lims2 SDK 基础异常"""
 
-    pass
+    def __init__(self, message: str = ""):
+        # 自动在错误信息末尾添加版本号
+        if message and not message.endswith(f"(lims2-sdk v{__version__})"):
+            message = f"{message} (lims2-sdk v{__version__})"
+        super().__init__(message)
 
 
 class ConfigError(Lims2Error):
