@@ -3,21 +3,27 @@
 通过 STS 临时凭证上传文件到阿里云 OSS，支持大文件断点续传
 """
 
+import logging
 from pathlib import Path
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Callable, Optional, Union
 
 import oss2
 
 from .exceptions import APIError
+from .network import network_retry
+from .oss_base import OSSMixin
 from .utils import (
     format_file_size,
     generate_unique_filename,
     get_file_size,
+    get_temp_dir,
     handle_api_response,
 )
 
+logger = logging.getLogger(__name__)
 
-class StorageService:
+
+class StorageService(OSSMixin):
     """存储服务
 
     通过阿里云 OSS 提供文件存储功能，支持：
@@ -39,8 +45,9 @@ class StorageService:
         self.client = client
         self.config = client.config
         self.session = client.session
-        # STS 凭证缓存，避免频繁请求
-        self._sts_cache = {}
+
+        # 初始化OSS混入功能
+        self.__init_oss__()
 
         # 校验必需的配置项
         required = ["api_url", "team_id", "token"]
@@ -59,7 +66,7 @@ class StorageService:
         description: Optional[str] = None,
         progress_callback: Optional[Callable] = None,
         base_path: Optional[str] = None,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """上传单个文件到 OSS
 
         Args:
@@ -74,7 +81,7 @@ class StorageService:
             base_path: OSS 中的基础路径（可选）
 
         Returns:
-            Dict[str, Any]: 上传结果，包含文件信息和 OSS 键名
+            dict[str, Any]: 上传结果，包含文件信息和 OSS 键名
 
         Raises:
             FileNotFoundError: 文件不存在
@@ -86,13 +93,13 @@ class StorageService:
             ...     progress_callback=lambda consumed, total: print(f"{consumed/total*100:.1f}%")
             ... )
             >>> print(result['oss_key'])
-            biofile/proj_001/analysis1/data_123456.csv
+            biofile/test/proj_001/analysis1/data_123456.csv
         """
         file_path = Path(file_path)
         if not file_path.exists():
             raise FileNotFoundError(f"文件不存在: {file_path}")
 
-        # 构建 OSS 键名：biofile/project_id/[base_path/]filename
+        # 构建 OSS 键名：biofile/{env}/project_id/[base_path/]filename
         if not key:
             # 如果没有指定 base_path，对单文件上传使用 analysis_node/sample_id 作为默认路径
             if base_path is None:
@@ -129,7 +136,8 @@ class StorageService:
         sample_id: Optional[str] = None,
         recursive: bool = True,
         base_path: Optional[str] = None,
-    ) -> List[Dict[str, Any]]:
+        progress_callback: Optional[Callable] = None,
+    ) -> list[dict[str, Any]]:
         """批量上传目录中的所有文件
 
         Args:
@@ -140,9 +148,10 @@ class StorageService:
             sample_id: 样本 ID（可选）
             recursive: 是否递归上传子目录（默认 True）
             base_path: OSS 中的基础路径（可选）
+            progress_callback: 进度回调函数，接收(current, total, filename)参数
 
         Returns:
-            List[Dict[str, Any]]: 每个文件的上传结果列表
+            list[dict[str, Any]]: 每个文件的上传结果列表
 
         Raises:
             FileNotFoundError: 目录不存在
@@ -174,8 +183,13 @@ class StorageService:
         files = [f for f in dir_path.glob(pattern) if f.is_file()]
 
         results = []
-        for file_path in files:
+        total_files = len(files)
+        for i, file_path in enumerate(files, 1):
             try:
+                # 进度回调
+                if progress_callback:
+                    progress_callback(i, total_files, file_path.name)
+
                 # 保持相对路径结构，包含原始目录名
                 relative_path = file_path.relative_to(dir_path)
                 # 添加原始目录名作为前缀
@@ -200,6 +214,73 @@ class StorageService:
 
         return results
 
+    def download_file(
+        self,
+        oss_key: str,
+        local_path: Union[str, Path],
+        project_id: str,
+        progress_callback: Optional[Callable] = None,
+    ) -> dict[str, Any]:
+        """从 OSS 下载文件到本地
+
+        Args:
+            oss_key: OSS 文件键名
+            local_path: 本地保存路径
+            project_id: 项目 ID
+            progress_callback: 进度回调函数，签名为 callback(consumed_bytes, total_bytes)
+
+        Returns:
+            dict[str, Any]: 下载结果信息
+
+        Raises:
+            FileNotFoundError: OSS 文件不存在
+            APIError: OSS 访问失败
+        """
+        local_path = Path(local_path)
+
+        # 确保本地目录存在
+        local_path.parent.mkdir(parents=True, exist_ok=True)
+
+        # 获取 OSS bucket
+        bucket = self._get_oss_bucket(project_id)
+
+        try:
+            # 检查文件是否存在并获取文件信息
+            try:
+                obj_info = bucket.get_object_meta(oss_key)
+                file_size = obj_info.content_length
+            except oss2.exceptions.NoSuchKey:
+                raise FileNotFoundError(f"OSS 文件不存在: {oss_key}")
+
+            # 直接下载文件
+            bucket.get_object_to_file(
+                oss_key, str(local_path), progress_callback=progress_callback
+            )
+
+            # 验证下载完成
+            if not local_path.exists():
+                raise APIError(f"下载失败: 文件未创建 {local_path}")
+
+            downloaded_size = get_file_size(local_path)
+            if downloaded_size != file_size:
+                raise APIError(
+                    f"下载不完整: 期望 {file_size} 字节，实际 {downloaded_size} 字节"
+                )
+
+            return {
+                "oss_key": oss_key,
+                "local_path": str(local_path),
+                "file_name": local_path.name,
+                "file_size": file_size,
+                "file_size_readable": format_file_size(file_size),
+                "success": True,
+            }
+
+        except oss2.exceptions.AccessDenied:
+            raise APIError(f"OSS 访问权限不足: {oss_key}")
+        except oss2.exceptions.RequestError as e:
+            raise APIError(f"OSS 请求失败: {e}")
+
     def file_exists(self, oss_key: str, project_id: str) -> bool:
         """检查文件是否存在"""
         try:
@@ -208,7 +289,7 @@ class StorageService:
         except Exception:
             return False
 
-    def get_file_info(self, oss_key: str, project_id: str) -> Dict[str, Any]:
+    def get_file_info(self, oss_key: str, project_id: str) -> dict[str, Any]:
         """获取文件详细信息"""
         bucket = self._get_oss_bucket(project_id)
 
@@ -232,26 +313,6 @@ class StorageService:
         except oss2.exceptions.NoSuchKey:
             raise FileNotFoundError(f"文件不存在: {oss_key}")
 
-    def _get_oss_bucket(self, project_id: str) -> oss2.Bucket:
-        """获取配置了 STS 认证的 OSS Bucket 对象
-
-        Args:
-            project_id: 项目 ID，用于获取对应的 STS 凭证
-
-        Returns:
-            oss2.Bucket: 配置了临时凭证的 Bucket 实例
-
-        Raises:
-            APIError: STS 凭证获取失败
-        """
-        sts_info = self._get_sts_token(project_id)
-        auth = oss2.StsAuth(
-            sts_info["access_key_id"],
-            sts_info["access_key_secret"],
-            sts_info["security_token"],
-        )
-        return oss2.Bucket(auth, sts_info["endpoint"], sts_info["bucket_name"])
-
     def _build_oss_key(
         self,
         project_id: str,
@@ -261,7 +322,8 @@ class StorageService:
         """构建 OSS 文件键名
 
         生成规则：
-        - 基础路径：biofile/project_id/[base_path/]
+        - 基础路径：biofile/{env}/project_id/[base_path/]
+        - 环境前缀：生产环境使用media，测试环境使用test
         - 文件名：添加随机后缀避免冲突
         - 始终保持目录结构
 
@@ -275,12 +337,14 @@ class StorageService:
 
         Example:
             >>> self._build_oss_key("proj_001", "data.csv", base_path="results")
-            "biofile/proj_001/results/data_123456.csv"
+            "biofile/media/proj_001/results/data_123456.csv"  # 生产环境
 
             >>> self._build_oss_key("proj_001", "subdir/file.txt", "results")
-            "biofile/proj_001/results/subdir/file_123456.txt"
+            "biofile/test/proj_001/results/subdir/file_123456.txt"  # 测试环境
         """
-        parts = ["biofile", project_id]
+        # 使用环境相关的路径前缀
+        env_prefix = self._get_oss_path_prefix()
+        parts = ["biofile", env_prefix, project_id]
         if base_path:
             parts.append(base_path)
 
@@ -295,6 +359,12 @@ class StorageService:
             unique_filename = generate_unique_filename(path_obj.stem, path_obj.suffix)
             return "/".join(parts) + "/" + unique_filename
 
+    def _get_resumable_store_dir(self) -> str:
+        """获取可用的断点续传临时目录"""
+        custom_dir = getattr(self.config, "custom_temp_dir", None)
+        return get_temp_dir(custom_dir, purpose="oss-upload")
+
+    @network_retry(max_retries=3, base_delay=2.0, max_delay=30.0)
     def _upload_to_oss(
         self,
         bucket: oss2.Bucket,
@@ -314,27 +384,46 @@ class StorageService:
             - 超过 10MB 的文件自动使用分片上传
             - 每个分片 5MB，使用 3 个线程并发上传
             - 支持断点续传，中断后可恢复
-            - 临时文件存储在 /tmp 目录
+            - 临时文件存储在可写的临时目录中
             - 上传完成后自动清理临时文件
         """
-        temp_store = oss2.ResumableStore(root="/tmp")
+        # 获取可用的临时目录
+        temp_root = self._get_resumable_store_dir()
+
+        # 创建断点续传存储对象
+        temp_store = oss2.ResumableStore(root=temp_root)
+
         try:
+            # 计算文件大小用于调整参数
+            file_size_mb = get_file_size(file_path) / (1024 * 1024)
+
+            # 根据网络质量调整并发数
+            num_threads = min(
+                3, max(1, int(file_size_mb / 50))
+            )  # 大文件减少并发避免超时
+
             oss2.resumable_upload(
                 bucket,
                 key,
                 str(file_path),
                 store=temp_store,
                 multipart_threshold=10 * 1024 * 1024,  # 10MB 阈值
-                part_size=5 * 1024 * 1024,  # 5MB 分片
-                num_threads=3,  # 3 线程并发
+                part_size=8 * 1024 * 1024,  # 增大分片减少请求次数
+                num_threads=num_threads,  # 动态并发数
                 progress_callback=progress_callback,
             )
         finally:
             # 清理断点续传的临时文件
+            # 注意：新版本的 oss2.ResumableStore 可能没有 remove 方法
+            # 临时文件会在上传成功后自动清理
             try:
-                temp_store.remove(key)
+                if hasattr(temp_store, "remove"):
+                    temp_store.remove(key)
+                elif hasattr(temp_store, "delete"):
+                    temp_store.delete(key)
+                # 如果都没有，让 oss2 自己管理临时文件
             except Exception:
-                pass
+                pass  # 忽略清理错误
 
     def _create_file_record(
         self,
@@ -345,7 +434,7 @@ class StorageService:
         file_category: str,
         sample_id: Optional[str],
         description: Optional[str],
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """在后端数据库创建文件上传记录
 
         Args:
@@ -358,7 +447,7 @@ class StorageService:
             description: 文件描述（可选）
 
         Returns:
-            Dict[str, Any]: 包含文件信息的结果，OSS 上传成功但记录失败时包含 error 字段
+            dict[str, Any]: 包含文件信息的结果，OSS 上传成功但记录失败时包含 error 字段
 
         Note:
             - 即使数据库记录失败，OSS 上传已完成，文件仍可访问
@@ -426,7 +515,7 @@ class StorageService:
         project_id: str,
         content_type: str = None,
         etag: str = None,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """解析 OSS 文件元数据为标准格式
 
         Args:
@@ -438,12 +527,12 @@ class StorageService:
             etag: 文件 ETag（可选）
 
         Returns:
-            Dict[str, Any]: 标准化的文件信息
+            dict[str, Any]: 标准化的文件信息
 
         Note:
             - 自动解析键名中的 analysis_node 和 sample_id
             - 处理不同格式的时间戳
-            - 键名格式：biofile/project_id/analysis_node/[sample_id]/filename
+            - 键名格式：biofile/{env}/project_id/analysis_node/[sample_id]/filename
         """
         key_parts = oss_key.split("/")
 
@@ -471,62 +560,10 @@ class StorageService:
         if etag:
             file_info["etag"] = etag
 
-        # 解析路径结构: biofile/project_id/analysis_node/[sample_id]/filename
-        if len(key_parts) >= 4:
-            file_info["analysis_node"] = key_parts[2]
-            if len(key_parts) >= 5:
-                file_info["sample_id"] = key_parts[3]
+        # 解析路径结构: biofile/{env}/project_id/analysis_node/[sample_id]/filename
+        if len(key_parts) >= 5:
+            file_info["analysis_node"] = key_parts[3]
+            if len(key_parts) >= 6:
+                file_info["sample_id"] = key_parts[4]
 
         return file_info
-
-    def _get_sts_token(self, project_id: str) -> Dict[str, Any]:
-        """获取阿里云 STS 临时访问凭证
-
-        Args:
-            project_id: 项目 ID
-
-        Returns:
-            Dict[str, Any]: STS 凭证信息，包含：
-                - access_key_id: 临时访问密钥 ID
-                - access_key_secret: 临时访问密钥
-                - security_token: 安全令牌
-                - endpoint: OSS 服务端点
-                - bucket_name: OSS 存储桶名称
-
-        Raises:
-            APIError: 获取 STS 凭证失败
-
-        Note:
-            - 使用简单的内存缓存避免频繁请求
-            - 缓存键格式：project_id:team_id
-            - STS 凭证有时效性，过期后需重新获取
-        """
-        cache_key = f"{project_id}:{self.config.team_id}"
-
-        # 简单缓存机制
-        if cache_key in self._sts_cache:
-            return self._sts_cache[cache_key]
-
-        # 从 API 获取新的 STS 凭证
-        params = {"team_id": self.config.team_id} if self.config.team_id else {}
-        response = self.session.get(
-            f"{self.config.api_url}/get_data/aliyun_sts/",
-            params=params,
-            timeout=self.config.timeout,
-        )
-
-        result = handle_api_response(response, "获取STS凭证")
-        raw_data = result.get("record", result)
-
-        # 构建标准化的凭证信息
-        token_data = {
-            "access_key_id": raw_data.get("AccessKeyId"),
-            "access_key_secret": raw_data.get("AccessKeySecret"),
-            "security_token": raw_data.get("SecurityToken"),
-            "endpoint": self.config.oss_endpoint,
-            "bucket_name": self.config.oss_bucket_name,
-        }
-
-        # 缓存凭证并返回
-        self._sts_cache[cache_key] = token_data
-        return token_data
